# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['properjpg']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=9.0.1,<10.0.0']

entry_points = \
{'console_scripts': ['properjpg = properjpg.cli:run']}

setup_kwargs = {
    'name': 'properjpg',
    'version': '0.1.1',
    'description': 'Make any image ready for the web. Fast.',
    'long_description': 'ProperJPG\n=========\n\n*Make any image ready for the web. Fast.*\n\nProperJPG is a super fast, lightweight CLI app that converts images to jpg. It also resizes them!\n\n|\n\n**Actively soliciting contributors!**\n\nFeel free to open a pull request in case you find an issue or a way to improve the \napp. New features are also welcome, considering they don\'t add unecessary complexity to the\nuser experience.\n\nInstallation\n------------\n\n- `Regular`_\n- `Developer`_\n\nRegular\n~~~~~~~\n**Pipx (recommended)**\n   \n::\n\n   pipx install properjpg\n\n**Pip**\n\n::\n\n   pip install properjpg\n\nDeveloper\n~~~~~~~~~\n**Poetry**\n\n::\n\n   poetry add properjpg\n\n**Git**\n\n::\n\n   git clone https://github.com/vitorrloureiro/properjpg\n\nFeatures\n--------\n\n- `Smart resize`_\n- `Multiprocessing`_\n\nSmart resize\n~~~~~~~~~~~~\n\nIt has a super cool \'smart resize\' functionality.\nIt allows you to set a max width and height, and you can be sure that\nevery image compressed by it will be no larger or taller than what you\nspecify. This \'smart resize\' mode makes sure to don\'t resize images\nthat doesn\'t need to, and also takes in account if it\'s best for an\nimage to be resized based on it\'s width or height.\n\nMultiprocessing\n~~~~~~~~~~~~~~~\n\nThis app uses the multiprocessing module to leverage all the power on your computer.\nIt\'ll work faster if you have multiple cores.\n\nHow it works?\n-------------\n**This app works in two modes:**\n\n- `"Single file" mode`_\n- `"Directory" mode`_\n\n\n\n\n\n"Single file" mode\n~~~~~~~~~~~~~~~~~~\nInput an image path and the desired output path.\n\nUsage:\n   \n::\n\n   properjpg [input_path] [output_path] -wi=[max_width] -he=[max_height]\n\n\n"Directory" mode\n~~~~~~~~~~~~~~~~\nThis is where this app really shines. Input a directory path and a desired destination\npath and the app will clone the folder struct of the original directory on the output path.\nThen it will look for all images in the input folder and will try to convert (and\nresize, if you setted it to) them.\n\nProperJPG uses multiprocessing to speed up the process.\n\nUsage:\n\n::\n\n   properjpg [input_path] [output_path] -d -wi=[max_width] -he=[max_height]\n\n\nNotes\n-----\nThis software is in Alpha stage. A lot of things may change, including syntax and dependencies. I\'m looking for help\nto improve this tool in terms of speed, features and code readability. Feel free to make suggestions and appoint improvements!.\nAlso feel free to help me improve the tests 😅\n\nThe goal is to always keep the code with 100% test coverage.\n\nContributing\n------------\n\nRequirements\n~~~~~~~~~~~~\n\nThis repository automatically lints code with flake8 and black, and also runs mypy\nand pytest. Pull requests must pass in all those tests.\n\n- `black <https://github.com/psf/black>`_\n- `flake8 <https://github.com/PyCQA/flake8>`_\n- `mypy <https://github.com/python/mypy>`_\n- `pytest <https://github.com/pytest-dev/pytest>`_\n\nRoadmap\n~~~~~~~\n\n- Improve testing.\n- Improve Docs.\n- Improve UI (maybe switch to Click?).\n- Improve Performance.\n\nKnown Issues\n~~~~~~~~~~~~\n\nClient\n......\n- None\n\nDev\n...\n- Tests are incomplete.\n\nLicense\n-------\n**MIT**\n',
    'author': 'Vitor Loureiro',
    'author_email': 'miseravel.cruller-0o@icloud.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/vitorrloureiro/properjpg',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
